@@ -19,8 +19,10 @@ def generate(directory=".") -> str:
             .strip()
         )
     except subprocess.CalledProcessError:
-        raise GitDirectoryError("Directory not a git repository")
-    return time.strftime("%y.%j.%k%M%S", time.localtime(commitDate))
+        raise GitDirectoryError(
+            "Directory not a git repository"
+        ) from subprocess.CalledProcessError
+    return time.strftime("%y.%j.%H%M%S", time.localtime(commitDate))
 
 
 if __name__ == "__main__":
